==> mp-package-cli-1.7.1.tgz: package/builder_web.js <==
const fs = require('fs');
const path = require('path');
const JSZip = require('jszip');
const { getAllFiles } = require('./folder');

const with_fetch = import('node-fetch').then(({ Blob }) => {
  globalThis.Blob = Blob;
  JSZip.support.blob = true;
});

module.exports = async function (dir, package_info) {
  try {
    const public_url = path.join(dir, 'dist', process.env.PUBLIC_URL);
    const manifest_txt = fs.readFileSync(path.join(public_url, 'asset-manifest.json')).toString('utf8');
    const manifest = JSON.parse(manifest_txt);
    const Entrypoints = manifest.entrypoints;

    const zip = JSZip();

    const files = getAllFiles(path.join(public_url, package_info.targetName));
    files.forEach(file => {
      if (file.endsWith('.map')) return;
      zip.file(file, fs.readFileSync(path.join(public_url, package_info.targetName, file)));
    });

    try {
      const libman_txt = fs.readFileSync(path.join(dir, 'libman.json')).toString('utf8');
      const libman = JSON.parse(libman_txt);
      libman.libraries.forEach(lib => {
        const files = getAllFiles(path.join(dir, lib.destination));
        files.forEach(file => {
          zip.file(path.join(lib.library, file), fs.readFileSync(path.join(dir, lib.destination, file)));
        });
      });
    } catch (e) { }

    await with_fetch;
    const Zip = await zip.generateAsync({ type: 'blob', compression: 'DEFLATE', compressionOptions: { level: 5 } });

    return {
      "ID": package_info.id,
      "Name": package_info.targetName,
      "Code": package_info.targetCode,
      "Version": package_info.version,
      "Info": package_info.description,
      "Author": package_info.author,
      Entrypoints,
      Zip,
    };
  } catch (e) {
    if (e.code !== 'ENOENT') throw e;
  }
}

==> mp-package-cli-1.8.3.tgz: package/builder_web.js <==
const fs = require('fs');
const path = require('path');
const JSZip = require('jszip');
const { getAllFiles } = require('./folder');

const with_fetch = import('node-fetch').then(({ Blob }) => {
  globalThis.Blob = Blob;
  JSZip.support.blob = true;
});

module.exports = async function (dir, package_info) {
  try {
    const public_url = path.join(dir, 'dist', process.env.PUBLIC_URL);
    const Entrypoints = [];
    const zip = JSZip();

    const files = getAllFiles(path.join(public_url, package_info.targetName));
    files.forEach(file => {
      if (file.endsWith('.map')) return;
      zip.file(file, fs.readFileSync(path.join(public_url, package_info.targetName, file)));
    });

    try {
      const libman_txt = fs.readFileSync(path.join(dir, 'libman.json')).toString('utf8');
      const libman = JSON.parse(libman_txt);
      libman.libraries.forEach(lib => {
        const files = getAllFiles(path.join(dir, lib.destination));
        files.forEach(file => {
          const fullname = path.join(lib.library, file);
          zip.file(fullname, fs.readFileSync(path.join(dir, lib.destination, file)));
          if (lib.entrypoints && fullname.toLocaleLowerCase().endsWith('.js')) {
            Entrypoints.push(package_info.targetName + '/' + fullname);
          }
        });
      });
    } catch (e) { }

    const manifest_txt = fs.readFileSync(path.join(public_url, 'asset-manifest.json')).toString('utf8');
    const manifest = JSON.parse(manifest_txt);
    Entrypoints.push(...manifest.entrypoints);

    await with_fetch;
    const Zip = await zip.generateAsync({ type: 'blob', compression: 'DEFLATE', compressionOptions: { level: 5 } });

    return {
      "ID": package_info.id,
      "Name": package_info.targetName,
      "Code": package_info.targetCode,
      "Version": package_info.version,
      "Info": package_info.description,
      "Author": package_info.author,
      Entrypoints,
      Zip,
    };
  } catch (e) {
    if (e.code !== 'ENOENT') throw e;
  }
}
